@@ -18,11 +18,14 @@ from certbot.storage import ALL_FOUR
 from certbot.tests import storage_test
 from certbot.tests import util as test_util
 
-class BaseCertManagerTest(unittest.TestCase):
+from certbot.tests.util import TempDirTestCase
+
+
+class BaseCertManagerTest(TempDirTestCase):
     """Base class for setting up Cert Manager tests.
     """
     def setUp(self):
-        self.tempdir = tempfile.mkdtemp()
+        super(BaseCertManagerTest, self).setUp()
 
         os.makedirs(os.path.join(self.tempdir, "renewal"))
 
@@ -68,9 +71,6 @@ class BaseCertManagerTest(unittest.TestCase):
         config.write()
         return config
 
-    def tearDown(self):
-        shutil.rmtree(self.tempdir)
-
 
 class UpdateLiveSymlinksTest(BaseCertManagerTest):
     """Tests for certbot.cert_manager.update_live_symlinks
@@ -268,11 +268,11 @@ class LineageForCertnameTest(BaseCertManagerTest):
     """Tests for certbot.cert_manager.lineage_for_certname"""
 
     @mock.patch('certbot.util.make_or_verify_dir')
-    @mock.patch('certbot.storage.renewal_conf_files')
+    @mock.patch('certbot.storage.renewal_file_for_certname')
     @mock.patch('certbot.storage.RenewableCert')
-    def test_found_match(self, mock_renewable_cert, mock_renewal_conf_files,
+    def test_found_match(self, mock_renewable_cert, mock_renewal_conf_file,
         mock_make_or_verify_dir):
-        mock_renewal_conf_files.return_value = ["somefile.conf"]
+        mock_renewal_conf_file.return_value = "somefile.conf"
         mock_match = mock.Mock(lineagename="example.com")
         mock_renewable_cert.return_value = mock_match
         from certbot import cert_manager
@@ -281,13 +281,20 @@ class LineageForCertnameTest(BaseCertManagerTest):
         self.assertTrue(mock_make_or_verify_dir.called)
 
     @mock.patch('certbot.util.make_or_verify_dir')
-    @mock.patch('certbot.storage.renewal_conf_files')
-    @mock.patch('certbot.storage.RenewableCert')
-    def test_no_match(self, mock_renewable_cert, mock_renewal_conf_files,
+    @mock.patch('certbot.storage.renewal_file_for_certname')
+    def test_no_match(self, mock_renewal_conf_file,
         mock_make_or_verify_dir):
-        mock_renewal_conf_files.return_value = ["somefile.conf"]
-        mock_match = mock.Mock(lineagename="other.com")
-        mock_renewable_cert.return_value = mock_match
+        mock_renewal_conf_file.return_value = "other.com.conf"
+        from certbot import cert_manager
+        self.assertEqual(cert_manager.lineage_for_certname(self.cli_config, "example.com"),
+            None)
+        self.assertTrue(mock_make_or_verify_dir.called)
+
+    @mock.patch('certbot.util.make_or_verify_dir')
+    @mock.patch('certbot.storage.renewal_file_for_certname')
+    def test_no_renewal_file(self, mock_renewal_conf_file,
+        mock_make_or_verify_dir):
+        mock_renewal_conf_file.side_effect = errors.CertStorageError()
         from certbot import cert_manager
         self.assertEqual(cert_manager.lineage_for_certname(self.cli_config, "example.com"),
             None)
@@ -298,11 +305,11 @@ class DomainsForCertnameTest(BaseCertManagerTest):
     """Tests for certbot.cert_manager.domains_for_certname"""
 
     @mock.patch('certbot.util.make_or_verify_dir')
-    @mock.patch('certbot.storage.renewal_conf_files')
+    @mock.patch('certbot.storage.renewal_file_for_certname')
     @mock.patch('certbot.storage.RenewableCert')
-    def test_found_match(self, mock_renewable_cert, mock_renewal_conf_files,
+    def test_found_match(self, mock_renewable_cert, mock_renewal_conf_file,
         mock_make_or_verify_dir):
-        mock_renewal_conf_files.return_value = ["somefile.conf"]
+        mock_renewal_conf_file.return_value = "somefile.conf"
         mock_match = mock.Mock(lineagename="example.com")
         domains = ["example.com", "example.org"]
         mock_match.names.return_value = domains
@@ -313,15 +320,10 @@ class DomainsForCertnameTest(BaseCertManagerTest):
         self.assertTrue(mock_make_or_verify_dir.called)
 
     @mock.patch('certbot.util.make_or_verify_dir')
-    @mock.patch('certbot.storage.renewal_conf_files')
-    @mock.patch('certbot.storage.RenewableCert')
-    def test_no_match(self, mock_renewable_cert, mock_renewal_conf_files,
+    @mock.patch('certbot.storage.renewal_file_for_certname')
+    def test_no_match(self, mock_renewal_conf_file,
         mock_make_or_verify_dir):
-        mock_renewal_conf_files.return_value = ["somefile.conf"]
-        mock_match = mock.Mock(lineagename="example.com")
-        domains = ["example.com", "example.org"]
-        mock_match.names.return_value = domains
-        mock_renewable_cert.return_value = mock_match
+        mock_renewal_conf_file.return_value = "somefile.conf"
         from certbot import cert_manager
         self.assertEqual(cert_manager.domains_for_certname(self.cli_config, "other.com"),
             None)
@@ -435,9 +437,6 @@ class DuplicativeCertsTest(storage_test.BaseRenewableCertTest):
         self.config.write()
         self._write_out_ex_kinds()
 
-    def tearDown(self):
-        shutil.rmtree(self.tempdir)
-
     @mock.patch('certbot.util.make_or_verify_dir')
     def test_find_duplicative_names(self, unused_makedir):
         from certbot.cert_manager import find_duplicative_certs
